@@ -79,4 +79,31 @@ sub template_email : Global('template_email') {
     }
 }
 
+sub mason_email : Global('mason_email') {
+    my ($self, $c, @args) = @_;
+
+    $c->stash->{time} = $c->req->params->{time} || time;
+
+    $c->stash->{email} = {
+        to      => 'test-email@example.com',
+        from    => 'no-reply@example.com',
+        subject => 'Just a test',
+        content_type => 'multipart/alternative',
+        templates => [
+            qw{text_plain/test.m},
+            qw{text_html/test.m}
+        ]
+    };
+
+    $c->forward('TestApp::View::Email::Template');    
+
+    if ( scalar( @{ $c->error } ) ) {
+        $c->res->status(500);
+        $c->res->body('Mason Email Failed');
+    } else {
+        $c->res->body('Mason Email Ok');
+    }
+}
+
+
 1;
